@@ -1,10 +1,8 @@
 #include "Benchmark.h"
-#include <tagcoll/Exception.h>
 
 #include <iostream>
 
 using namespace std;
-using namespace Tagcoll;
 
 int main(int argc, const char* argv[])
 {
@@ -24,12 +22,10 @@ int main(int argc, const char* argv[])
 		}
 
 		return 0;
-	} catch (Exception& e) {
-		cerr << e.type() << ": " << e.desc() << endl;
-	} catch (exception& e) {
+	} catch (std::exception& e) {
 		cerr << e.what() << endl;
+		return 1;
 	}
-	return 1;
 }
 
 /* vim:set ts=4 sw=4: */
