@@ -105,7 +105,7 @@
 #define TAG SAVED_TAG
 #undef SAVED_TAG
 
-#define YYSTYPE	Tagcoll::Expression
+#define YYSTYPE	tagcoll::Expression
 //#define YYDEBUG 1
 
 extern int yylex();
@@ -1123,7 +1123,7 @@ yyreduce:
     {
         case 2:
 #line 47 "Tagexpr_parser_y.yy"
-    { Tagcoll::TagexprParser::instance()->setResult((yyvsp[0])); }
+    { tagcoll::TagexprParser::instance()->setResult((yyvsp[0])); }
     break;
 
   case 3:
@@ -1429,7 +1429,7 @@ yyreturn:
 
 void yyerror(const char* s)
 {
-	Tagcoll::TagexprParser::instance()->addError(s);
+	tagcoll::TagexprParser::instance()->addError(s);
 }
 
 /* vim:set syntax=yacc ts=4 sw=4: */
